@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 12719 2021-01-31 06:32:27Z Casey $
+# $Id: admin.py 12720 2021-01-31 06:51:53Z Casey $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2021-01-31 14:32:27 +0800 (Sun, 31 Jan 2021) $
-# $Revision: 12719 $
+# $Date: 2021-01-31 14:51:53 +0800 (Sun, 31 Jan 2021) $
+# $Revision: 12720 $
 
 import os
 import datetime
@@ -53,7 +53,7 @@ TEXT_SUB_FILE_NAME = [
 IMAGE_SUB_FILE_NAME = [
     'jpg', 'png', 'jpeg', 'bmp', 'gif', 'tif',
 ]
-EXCEL_SUB_FILE_NAME = [
+FILE_SUB_FILE_NAME = [
     'xlsx',
 ]
 
@@ -64,7 +64,7 @@ class FolderFrom(forms.ModelForm):
         model = Static
         exclude = ('parent', 'type', 'name')
 
-class ExcelFrom(forms.ModelForm):
+class FileFrom(forms.ModelForm):
     file = forms.FileField(
         label=_('File'), required=False)
 
@@ -100,12 +100,6 @@ def createVersion(model, node, conflict=False):
     dirName = node.dirName
     checksum = hashlib.md5(data).hexdigest()
 
-    if subFileName == 'xlsx':
-        randomDigits = ''.join(random.choice(string.digits) for _ in range(2))
-        randomDigits2 = ''.join(random.choice(string.digits) for _ in range(2))
-        randomDigits3 = ''.join(random.choice(string.digits) for _ in range(2))
-        checksum = hashlib.md5(f'{data}\\{randomDigits}\\{randomDigits2}\\{randomDigits3}'.encode('utf-8')).hexdigest()
-
     createFile = False
 
     if Version.objects.filter(dirName=dirName).exists():
@@ -334,8 +328,8 @@ class BaseFileAdmin(admin.ModelAdmin):
             form.base_fields['content'].initial = data
         elif subFileName in IMAGE_SUB_FILE_NAME:
             form = ImageFrom
-        elif subFileName in EXCEL_SUB_FILE_NAME:
-            form = ExcelFrom
+        elif subFileName in FILE_SUB_FILE_NAME:
+            form = FileFrom
         else:
             form = FolderFrom
 
@@ -401,6 +395,13 @@ class BaseFileAdmin(admin.ModelAdmin):
                         data = f.write(data)
                 else:
                     pass
+
+            elif subFileName in FILE_SUB_FILE_NAME:
+                file = request.FILES.get('file')
+
+                with open(fullPath, 'wb') as f:
+                    data = f.write(file.read())
+
             logger.info("File has modified: %s" % obj.path)
             version = createVersion(self.model, obj)
 
